@@ -5,8 +5,7 @@ from models import *
 class PhotoForm(ModelForm):
 	class Meta:
 		model = Photo
-		exclude = {'approved',}
+		exclude = ('approved',)
 		widgets = {
             'message': forms.Textarea(attrs={'cols': 80, 'rows': 20}),
         }
-		
\ No newline at end of file
